@@ -1,9 +1,9 @@
 package Log::ger::Output::Screen;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-07'; # DATE
+our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger-Output-Screen'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use strict;
 use warnings;
@@ -21,6 +21,10 @@ our %colors = (
 
 our %level_map;
 
+sub meta { +{
+    v => 1,
+} }
+
 sub _pick_color {
     my $level = shift;
     if (defined(my $c = $colors{$level})) {
@@ -79,7 +83,7 @@ sub get_hooks {
                 my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
                 my $outputter = sub {
                     my ($per_target_conf, $msg, $per_msg_conf) = @_;
-                    my $level = $per_msg_conf ? $per_msg_conf->{level} : $hook_args{level};
+                    my $level; $level = $per_msg_conf->{level} if $per_msg_conf; $level = $hook_args{level} unless defined $level;
                     if ($formatter) {
                         $msg = $formatter->($msg);
                     }
@@ -111,7 +115,7 @@ Log::ger::Output::Screen - Output log to screen
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
